@@ -42,110 +42,10 @@ char pause_chatter[CHAT_LINE_COUNT][CHAT_LINE_WIDTH];
 extern NetSocket client;
 extern int client_is_connected;
 
+#define MAX_CLIENT_TOPIC_COUNT 5
 int client_topic_count = 4;
-char *client_topics[] = {
-    "Challenges",
-    "Channels",
-    "Console Commands",
-    "Game Rules",
-    "Transfers"
-};
-char *client_helps[] = {
-  "To challenge a user you first have to select him/her in the " 
-  "upper right list and the levelset you want to play "
-  "from the list below. Then you adjust the game settings to your "
-  "likings and hit the 'Challenge' button which will send your "
-  "challenge to the other user who will either accept or decline. "
-  "If (s)he accepts a direct connection will be established and the "
-  "game will start.##"
-  "DIFFICULTY: This influences ball speed, paddle size and score as for "
-  "single player modus. (1 = Easy, 2 = Medium, 3 = Hard)##"
-  "ROUNDS: This is the number of rounds played per level. Winning a "
-  "round scores one point and the player with the most points wins "
-  "the match.##"
-  "FRAGS: In a pingpong level (no bricks) a player gains a frag everytime "
-  "the opponent looses a ball. 'frag' is a bad name for this, should be "
-  "pingpong winning score or something but 'frags' is simply shorter. "
-  "The player who hits this limit first "
-  "wins the round.#In levels with bricks this option is ignored "
-  "and the level is over after all bricks were cleared.##"
-  "BALLS: In a pingpong level (no bricks) each player may fire multiple "
-  "balls up to this number. If a player looses a ball he may fire it again.#"
-  "In normal levels (with bricks) this option is ignored and a gets a new ball "
-  "after five seconds penalty time.", 
-  "To switch a channel hit the 'C' button above the user list. "
-  "You can enter either an existing or a new channel. You "
-  "can only talk to and challenge users in the same channel.",
-  "User Console Commands:##" 
-  "/search <USER>#"
-  "Search for a user in all channels.##" 
-  "/version#"
-  "Display version of transmission protocol.##"
-  "/info#"
-  "Display current userlimit and frame rate.##" 
-  "Admin Console Commands:##" 
-  "/admin_says <MSG>#"
-  "Broadcast a message to all chatting users.##"
-  "/kick <USER>#"
-  "Kick user by that name.##"
-  "/addbot <NAME> <SPEED>#"
-  "Add a paddle bot. The speed is defined in pixels per second. 800 to 1000 is a good value.##"
-  "/delbot <NAME>#"
-  "Delete paddle bot.##"
-  "/set <VAR> <VALUE>#"
-  "Set a variable to a new value:#"
-  "  userlimit: is the number of users that may login. If decreased with too many users online"
-  " no one is kicked. This limit does not matter for admin login.#"
-  "  fps: is how many times a second the server calls up the communication and sends/receives"
-  " packets. This should not be too high to prevent network flooding. 40 is a good value.#"
-  "  packetlimit: if not -1 this is the number of packets parsed in one communication step. -1"
-  " which is the default means the queue is parsed until empty##"
-  "/addset <NAME>#"
-  "Load a new levelset that has been copied to the levels directory and make it available "
-  "to the users.##"
-  "/halt#"
-  "Halt server after 5 seconds and inform all users, even the playing ones, about this.",
-  "Basically you play the game as in single player mode but their "
-  "are some special things you might find useful to know.##"
-  "PINGPONG:#"
-  "The point here is to play it fast and to use all of your balls. "
-  "Use the right and left mouse button to fire the balls "
-  "while moving the paddle. Your opponent "
-  "will have trouble to reflect all balls if you do it right. "
-  "If you are not sure wether you got balls left click anyway. "
-  "Keep the button pressed for a while! The fire rate is restricted "
-  "to one ball every 500 milliseconds.##" 
-  "NORMAL:#"
-  "Your goal here is too gain more score than your opponent to win a "
-  "round. Basically you do this by clearing bricks and collecting extras "
-  "but there are some other ways as well:#"
-  "1) To loose a ball means to loose 10% score. After five seconds penalty "
-  "a new ball is created and you can continue playing.#"
-  "2) Hitting your opponents paddle with the plasma weapon will give you "
-  "1000 points while stealing him/her the same amount.#"
-  "3) Bonus/malus magnet will attract _all_ bonuses/maluses even those "
-  "released by your opponent.##"
-  "Note: If you pause the game by pressing 'p' a chat will pop up and you "
-  "can talk to your opponent.",
-  "You cannot offer someone your levelset unless this user "
-  "wants to receive your set which requires the following steps:#"
-  "1) select the user to whom you want to listen#"
-  "2) press the 'L' button above the levelset list#"
-  "3) wait for offer or cancel 'listening'#"
-  "The receiver is now ready and the sender has to:#"
-  "1) select the listening user#"
-  "2) select the levelset (s)he wants to transfer#"
-  "3) hit the 'T' button above the levelset list#"
-  "If the receiver has this levelset already located in "
-  "~/.lgames/lbreakout2-levels and it is up-to-date the transfer "
-  "does not take place otherwise the receiver is asked to confirm "
-  "and if (s)he does so the set is transferred to the home "
-  "directory and directly available if intended for network. (starts with 'MP_')#"
-  "NOTE: Only the challenger is required to have the levelset so you "
-  "don not have to transfer sets to play with someone. However if your opponent "
-  "likes your set and wants to challenge others with it both can engage into "
-  "a transfer."
-};
+char *client_topics[MAX_CLIENT_TOPIC_COUNT];
+char *client_helps[MAX_CLIENT_TOPIC_COUNT];
 Text *client_help_text = 0;
 
 /*
@@ -242,9 +142,114 @@ void client_data_create( void )
     client_channels = list_create( LIST_AUTO_DELETE, 0 /*just strings*/ );
     client_users = list_create( LIST_AUTO_DELETE, 0 );
     client_levelsets = list_create( LIST_AUTO_DELETE, 0 );
+    /* help defined here for localization reasons */
+    client_topics[0] = strdup(_("Challenges"));
+    client_topics[1] = strdup(_("Channels"));
+    client_topics[2] = strdup(_("Console Commands"));
+    client_topics[3] = strdup(_("Game Rules"));
+    client_topics[4] = strdup(_("Transfers"));
+    client_helps[0] = strdup(_(
+    "To challenge a user you first have to select him/her in the " 
+    "upper right list and the levelset you want to play "
+    "from the list below. Then you adjust the game settings to your "
+    "likings and hit the 'Challenge' button which will send your "
+    "challenge to the other user who will either accept or decline. "
+    "If (s)he accepts a direct connection will be established and the "
+    "game will start.##"
+    "DIFFICULTY: This influences ball speed, paddle size and score as for "
+    "single player modus. (1 = Easy, 2 = Medium, 3 = Hard)##"
+    "ROUNDS: This is the number of rounds played per level. Winning a "
+    "round scores one point and the player with the most points wins "
+    "the match.##"
+    "FRAGS: In a pingpong level (no bricks) a player gains a frag everytime "
+    "the opponent looses a ball. 'frag' is a bad name for this, should be "
+    "pingpong winning score or something but 'frags' is simply shorter. "
+    "The player who hits this limit first "
+    "wins the round.#In levels with bricks this option is ignored "
+    "and the level is over after all bricks were cleared.##"
+    "BALLS: In a pingpong level (no bricks) each player may fire multiple "
+    "balls up to this number. If a player looses a ball he may fire it again.#"
+    "In normal levels (with bricks) this option is ignored and a gets a new ball "
+    "after five seconds penalty time."));
+    client_helps[1] = strdup(_(
+    "To switch a channel hit the 'C' button above the user list. "
+    "You can enter either an existing or a new channel. You "
+    "can only talk to and challenge users in the same channel."));
+    client_helps[2] = strdup(_(
+    "User Console Commands:##" 
+    "/search <USER>#"
+    "Search for a user in all channels.##" 
+    "/version#"
+    "Display version of transmission protocol.##"
+    "/info#"
+    "Display current userlimit and frame rate.##" 
+    "Admin Console Commands:##" 
+    "/admin_says <MSG>#"
+    "Broadcast a message to all chatting users.##"
+    "/kick <USER>#"
+    "Kick user by that name.##"
+    "/addbot <NAME> <SPEED>#"
+    "Add a paddle bot. The speed is defined in pixels per second. 800 to 1000 is a good value.##"
+    "/delbot <NAME>#"
+    "Delete paddle bot.##"
+    "/set <VAR> <VALUE>#"
+    "Set a variable to a new value:#"
+    "  userlimit: is the number of users that may login. If decreased with too many users online"
+    " no one is kicked. This limit does not matter for admin login.#"
+    "  fps: is how many times a second the server calls up the communication and sends/receives"
+    " packets. This should not be too high to prevent network flooding. 40 is a good value.#"
+    "  packetlimit: if not -1 this is the number of packets parsed in one communication step. -1"
+    " which is the default means the queue is parsed until empty##"
+    "/addset <NAME>#"
+    "Load a new levelset that has been copied to the levels directory and make it available "
+    "to the users.##"
+    "/halt#"
+    "Halt server after 5 seconds and inform all users, even the playing ones, about this."));
+    client_helps[3] = /* xgettext:no-c-format */ strdup(_( "Basically you play the game as in single player mode but their "
+    "are some special things you might find useful to know.##"
+    "PINGPONG:#"
+    "The point here is to play it fast and to use all of your balls. "
+    "Use the right and left mouse button to fire the balls "
+    "while moving the paddle. Your opponent "
+    "will have trouble to reflect all balls if you do it right. "
+    "If you are not sure wether you got balls left click anyway. "
+    "Keep the button pressed for a while! The fire rate is restricted "
+    "to one ball every 500 milliseconds.##" 
+    "NORMAL:#"
+    "Your goal here is too gain more score than your opponent to win a "
+    "round. Basically you do this by clearing bricks and collecting extras "
+    "but there are some other ways as well:#"
+    "1) To loose a ball means to loose 10% score. After five seconds penalty "
+    "a new ball is created and you can continue playing.#"
+    "2) Hitting your opponents paddle with the plasma weapon will give you "
+    "1000 points while stealing him/her the same amount.#"
+    "3) Bonus/penalty magnet will attract _all_ bonuses/penalties even those "
+    "released by your opponent.##"
+    "Note: If you pause the game by pressing 'p' a chat will pop up and you "
+    "can talk to your opponent."));
+    client_helps[4] = strdup(_(
+    "You cannot offer someone your levelset unless this user "
+    "wants to receive your set which requires the following steps:#"
+    "1) select the user to whom you want to listen#"
+    "2) press the 'L' button above the levelset list#"
+    "3) wait for offer or cancel 'listening'#"
+    "The receiver is now ready and the sender has to:#"
+    "1) select the listening user#"
+    "2) select the levelset (s)he wants to transfer#"
+    "3) hit the 'T' button above the levelset list#"
+    "If the receiver has this levelset already located in "
+    "~/.lgames/lbreakout2-levels and it is up-to-date the transfer "
+    "does not take place otherwise the receiver is asked to confirm "
+    "and if (s)he does so the set is transferred to the home "
+    "directory and directly available if intended for network. (starts with 'MP_')#"
+    "NOTE: Only the challenger is required to have the levelset so you "
+    "don not have to transfer sets to play with someone. However if your opponent "
+    "likes your set and wants to challenge others with it both can engage into "
+    "a transfer."));
 }
 void client_data_delete( void )
 {
+    int i;
     if ( client_channels ) list_delete( client_channels ); 
     client_channels = 0;
     if ( client_users ) list_delete( client_users ); 
@@ -253,6 +258,11 @@ void client_data_delete( void )
     client_levelsets = 0;
     if ( client_help_text ) delete_text( client_help_text );
     client_help_text = 0;
+    for (i=0;i<MAX_CLIENT_TOPIC_COUNT;i++)
+    {
+        free(client_topics[i]);
+        free(client_helps[i]);
+    }
 }
 
 /*
@@ -345,5 +355,3 @@ void client_add_pausechatter( char *string, int info )
 {
     client_add_pause_chatter_intern( list_pausechatter, string, info );
 }
-
-
