@@ -125,14 +125,14 @@ static void client_parse_packet()
 				handled = 1;
 				break;
 			case MSG_ERROR:
-				client_printf_chatter( 1, "ERROR: %s", msg_read_string() );
+				client_printf_chatter( 1, _("ERROR: %s"), msg_read_string() );
 				handled = 1;
 				break;
 			case MSG_BUSY:
 				if ( client_state == CLIENT_AWAIT_ANSWER ||
 				     client_state == CLIENT_AWAIT_TRANSFER_CONFIRMATION )
 					client_popup_info( 
-						"%s is busy at the moment.", 
+						_("%s is busy at the moment."), 
 						mp_peer_name );
 				handled = 1;
 				break;
@@ -142,7 +142,7 @@ static void client_parse_packet()
 				break;
 			case MSG_SET_COMM_DELAY:
 				client_comm_delay = msg_read_int16();
-				printf( "comm_delay set to %i\n", client_comm_delay );
+				printf( _("comm_delay set to %i\n"), client_comm_delay );
 				handled = 1;
 				break;
 			/* chatter */
@@ -157,7 +157,7 @@ static void client_parse_packet()
 			/* users */
 			case MSG_ADD_USER:
 				num = msg_read_int32();
-				snprintf( name, 16, msg_read_string() ); name[15] = 0;
+				snprintf( name, 16, "%s", msg_read_string() ); name[15] = 0;
 				if ( msg_read_failed() ) break;
 				client_add_user( num, name );
 				gui_list_update( 
@@ -223,20 +223,20 @@ static void client_parse_packet()
 					client_transmit( CODE_BLUE, msglen, msgbuf );
 					break;
 				}
-				snprintf( mp_peer_name, 15, msg_read_string() );
-				snprintf( mp_levelset, 16, msg_read_string() );
+				snprintf( mp_peer_name, 15, "%s", msg_read_string() );
+				snprintf( mp_levelset, 16, "%s", msg_read_string() );
 				mp_diff = msg_read_int8();
 				mp_rounds = msg_read_int8();
 				mp_frags = msg_read_int8();
 				mp_balls = msg_read_int8();
 				if ( msg_read_failed() ) break;
-				client_popup_confirm( "    You have been challenged!##"\
+				client_popup_confirm( _("    You have been challenged!##"\
 						"    Challenger: %13s#"\
 						"    Levelset:   %13s#"\
 						"    Difficulty: %13s#"\
 						"    Rounds:     %13i#"\
 						"    Frag Limit: %13i#"\
-						"    Balls:      %13i",
+						"    Balls:      %13i"),
 						mp_peer_name, mp_levelset, mp_diff_names[mp_diff],
 						mp_rounds, mp_frags, mp_balls );
 				client_state = CLIENT_ANSWER;
@@ -246,14 +246,14 @@ static void client_parse_packet()
 				handled = 1;
 				if ( client_state != CLIENT_AWAIT_ANSWER ) break;
 				client_popup_info( 
-					"%s is too scared to accept your challenge.", 
+					_("%s is too scared to accept your challenge."), 
 					mp_peer_name );
 				break;
 			case MSG_CANCEL_GAME:
 				handled = 1;
 				if ( client_state != CLIENT_ANSWER ) break;
 				gui_widget_hide( dlg_confirm );
-				client_popup_info( "%s got cold feet.", mp_peer_name );
+				client_popup_info( _("%s got cold feet."), mp_peer_name );
 				break;
 			case MSG_ACCEPT_CHALLENGE:
 				handled = 1;
@@ -310,7 +310,7 @@ static void client_parse_packet()
 		}
 
 		if ( !handled ) {
-			printf( "chat: state %i: invalid message %x: skipping %i bytes\n",
+			printf( _("chat: state %i: invalid message %x: skipping %i bytes\n"),
 				client_state, type, net_buffer_cur_size - msg_read_pos );
 			msg_read_pos = net_buffer_cur_size;
 		}
@@ -355,4 +355,3 @@ void client_recv_packet( GuiWidget *widget, GuiEvent *event )
 	}
 #endif
 }
-
