@@ -170,6 +170,16 @@ static void comm_recv_local( void )
 	handle_mods();
 	local_game->mod = game->mod;
 
+    /* copy new level when altered in bonus level */
+    if (local_game->blRefreshBricks)
+    {
+        local_game->blRefreshBricks = 0;
+        /* HACK HACK HACK HACK.... did I mention this is a hack? And a really
+           bad one indeed. */
+        memcpy(game->bricks,local_game->bricks,sizeof(game->bricks));
+        client_redraw_all_bricks();
+    }
+    
 	return;
 }
 
@@ -199,7 +209,7 @@ static void comm_parse_packet()
 		switch ( type ) {
 			case MSG_SET_COMM_DELAY:
 				client_comm_delay = msg_read_int16();
-				printf( "comm_delay set to %i\n", client_comm_delay );
+				printf( _("comm_delay set to %i\n"), client_comm_delay );
 				handled = 1;
 				break;
 			case MSG_DISCONNECT:
@@ -208,7 +218,7 @@ static void comm_parse_packet()
 					close_pause_chat();
 
 				set_state( CS_FATAL_ERROR );
-				display_text( chat_font_error, "You've been disconnected." );
+				display_text( chat_font_error, _("You've been disconnected.") );
 				client_data_clear();
 				client_is_connected = 0;
 				handled = 1;
@@ -232,12 +242,12 @@ static void comm_parse_packet()
 				}
 				else {
 					set_state( CS_FATAL_ERROR );
-					display_text( chat_font_error, "corrupted level data" );
+					display_text( chat_font_error, _("corrupted level data") );
 				}
 				break;
 			case MSG_ADD_USER:
 				i = msg_read_int32();
-				snprintf( name, 16, msg_read_string() ); name[15] = 0;
+				snprintf( name, 16, "%s", msg_read_string() ); name[15] = 0;
 				if ( msg_read_failed() ) break;
 				client_add_user( i, name );
 				handled = 1;
@@ -253,7 +263,7 @@ static void comm_parse_packet()
 				handled = 1;
 				break;
 			case MSG_PAUSE:
-				open_pause_chat( "Remote player has paused the game." );
+				open_pause_chat( _("Remote player has paused the game.") );
 				handled = 1;
 				break;
 			case MSG_UNPAUSE:
@@ -364,7 +374,7 @@ static void comm_parse_packet()
 		}
 	
 		if ( !handled ) {
-			printf( "game: state %i: invalid message %x: skipping %i bytes\n",
+			printf( _("game: state %i: invalid message %x: skipping %i bytes\n"),
 				client_state, type, net_buffer_cur_size - msg_read_pos );
 			msg_read_pos = net_buffer_cur_size;
 		}
@@ -450,4 +460,3 @@ void comm_send_heartbeat( void )
 	}
 
 }
-
