@@ -68,13 +68,14 @@ void config_reset()
     /* player */
     config.player_count = 1;
     strcpy( config.player_names[0], "Michael" );
-    strcpy( config.player_names[1], "Mr.X" );
-    strcpy( config.player_names[2], "Mr.Y" );
-    strcpy( config.player_names[3], "Mr.Z" );
+    strcpy( config.player_names[1], _("Mr.X") );
+    strcpy( config.player_names[2], _("Mr.Y") );
+    strcpy( config.player_names[3], _("Mr.Z") );
     /* game */
     config.diff = 2;
     config.startlevel = 0;
     config.rel_warp_limit = 80;
+    config.addBonusLevels = 1;
     /* controls */
     config.k_left = SDLK_LEFT;
     config.k_right = SDLK_RIGHT;
@@ -94,12 +95,13 @@ void config_reset()
     config.i_key_speed = 500;
     config.key_speed = 0.5;
     config.random_angle = 1;
-    config.maxballspeed_int1000 = 700;
+    config.maxballspeed_int1000 = 900;
     config.maxballspeed_float = 0.7;
     /* sounds */
     config.sound = 1;
     config.volume = 8;
     config.speech = 1;
+    config.badspeech = 0;
     config.audio_buffer_size = 512;
     /* graphics */
     config.anim = 2;
@@ -117,7 +119,7 @@ void config_reset()
     /* multiplayer */
     strcpy( config.server, "217.160.141.22:8000" );
     strcpy( config.local_port, "8001" );
-    strcpy( config.username, "player" );
+    strcpy( config.username, _("player") );
     config.mp_diff = 1;
     config.mp_rounds = 1;
     config.mp_balls = 3;
@@ -157,6 +159,7 @@ void config_load( )
     parser_get_int( pd, "diff", &config.diff );
     parser_get_int( pd, "starting_level", &config.startlevel );
     parser_get_int( pd, "rel_warp_limit", &config.rel_warp_limit );
+    parser_get_int( pd, "add_bonus_levels", &config.addBonusLevels );
     parser_get_int( pd, "left", &config.k_left );
     parser_get_int( pd, "right", &config.k_right );
     parser_get_int( pd, "fire_left", &config.k_lfire );
@@ -176,6 +179,7 @@ void config_load( )
     parser_get_int( pd, "sound", &config.sound );
     parser_get_int( pd, "volume", &config.volume );
     parser_get_int( pd, "speech", &config.speech );
+    parser_get_int( pd, "badspeech", &config.badspeech );
     parser_get_int( pd, "audio_buffer_size", &config.audio_buffer_size );
     parser_get_int( pd, "anim", &config.anim );
     parser_get_int( pd, "fullscreen", &config.fullscreen );
@@ -226,6 +230,7 @@ void config_save( )
         fprintf( file, "diff%i\n", config.diff );
         fprintf( file, "starting_level%i\n", config.startlevel );
         fprintf( file, "rel_warp_limit%i\n", config.rel_warp_limit );
+        fprintf( file, "add_bonus_levels%i\n", config.addBonusLevels );
         fprintf( file, "left%i\n", config.k_left );
         fprintf( file, "right%i\n", config.k_right );
         fprintf( file, "fire_left%i\n", config.k_lfire );
@@ -243,6 +248,7 @@ void config_save( )
         fprintf( file, "sound%i\n", config.sound );
         fprintf( file, "volume%i\n", config.volume );
         fprintf( file, "speech%i\n", config.speech );
+        fprintf( file, "badspeech%i\n", config.badspeech );
         fprintf( file, "audio_buffer_size%i\n", config.audio_buffer_size );
         fprintf( file, "anim%i\n", config.anim );
         fprintf( file, "fullscreen%i\n", config.fullscreen );
@@ -265,4 +271,3 @@ void config_save( )
         fprintf( file, "mp_balls%i\n", config.mp_balls );
     }
 }
-
