@@ -39,6 +39,7 @@ typedef struct {
     int startlevel;
     int rel_warp_limit; /* percentage of bricks required to be destroyed 
                            before player may proceed to next level */
+    int addBonusLevels; /* add some bonus levels */
     /* controls */
     int k_left;
     int k_right;
@@ -63,6 +64,7 @@ typedef struct {
     int sound;
     int volume; /* 1 - 8 */
     int speech; /* enable speech? */
+    int badspeech; /* if speech allowed, allow swearing? */
     int audio_buffer_size;
     /* graphics */
     int anim;
