@@ -263,30 +263,30 @@ void editor_draw_status()
     int x = BRICK_WIDTH, y = ( MAP_HEIGHT - 1 ) * BRICK_HEIGHT - 2;
     int height = 10;
     /* locartion */
-    sprintf( str, "Location: %s", edit_file_name );
+    sprintf( str, _("Location: %s"), edit_file_name );
     mfont->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
     stk_font_write( mfont, stk_display, x, y, STK_OPAQUE, str );
     /* current level */
-    sprintf( str, "Current Level: %i/%i (Free: %i)", edit_cur_level_id + 1, edit_level_count, MAX_LEVELS - edit_level_count );
+    sprintf( str, _("Current Level: %i/%i (Free: %i)"), edit_cur_level_id + 1, edit_level_count, MAX_LEVELS - edit_level_count );
     mfont->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
     stk_font_write( mfont, stk_display, x, y + height, STK_OPAQUE, str );
     /* swap */
     mfont->align = STK_FONT_ALIGN_RIGHT | STK_FONT_ALIGN_TOP;
     if ( first_swap_level != -1 ) {
-        sprintf( str, "*** Level %i Marked For Swap ***", first_swap_level + 1 );
+        sprintf( str, _("*** Level %i Marked For Swap ***"), first_swap_level + 1 );
         stk_font_write( mfont, stk_display, stk_display->w - BRICK_WIDTH, y + height, STK_OPAQUE, str );
     }
     else {
         /* version */
-        sprintf( str, "Version: %s ", edit_version );
+        sprintf( str, _("Version: %s "), edit_version );
         stk_font_write( mfont, stk_display, stk_display->w - BRICK_WIDTH, y + height, STK_OPAQUE, str );
     }
     /* name and author */
     mfont->align = STK_FONT_ALIGN_LEFT | STK_FONT_ALIGN_TOP;
-    sprintf( str, "Title: %s", edit_cur_level->name );
+    sprintf( str, _("Title: %s"), edit_cur_level->name );
     stk_font_write( mfont, stk_display, BRICK_WIDTH + 2, ( MAP_HEIGHT - 5 ) * BRICK_HEIGHT + 5, STK_OPAQUE, str );
     mfont->align = STK_FONT_ALIGN_RIGHT | STK_FONT_ALIGN_TOP;
-    sprintf( str, "Author: %s", edit_cur_level->author );
+    sprintf( str, _("Author: %s"), edit_cur_level->author );
     stk_font_write( mfont, stk_display, stk_display->w - BRICK_WIDTH - 2, ( MAP_HEIGHT - 5 ) * BRICK_HEIGHT + 5, STK_OPAQUE, str );
 }
 /*
@@ -397,7 +397,7 @@ void editor_load_levels()
     /* if we got no level at all create an empty one */
     if ( edit_level_count == 0 ) {
         edit_level_count = 1;
-        edit_levels[0] = level_create_empty( "noname", "untitled" );
+        edit_levels[0] = level_create_empty( _("noname"), _("untitled") );
     }
     /* translate the character strings to editor info */
     for ( i = 0; i < edit_level_count; i++ )
@@ -481,7 +481,7 @@ void editor_handle_button( int type, int *full_update ) {
             }
             break;
         case BUTTON_LOAD:
-            if ( !confirm( font, "Discard All Changes? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Discard All Changes? y/n"), CONFIRM_YES_NO ) ) break;
             /* load levels and reset position if level doesn't exist */
             old_pos = edit_cur_level_id;
             editor_load_levels();
@@ -491,11 +491,11 @@ void editor_handle_button( int type, int *full_update ) {
             *full_update = 1;
             break;
         case BUTTON_SAVE:
-            if ( !confirm( font, "Save Changes? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Save Changes? y/n"), CONFIRM_YES_NO ) ) break;
             editor_save_levels();
             break;
         case BUTTON_CLEAR:
-            if ( !confirm( font, "Clear Level? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Clear Level? y/n"), CONFIRM_YES_NO ) ) break;
             author = strdup( edit_cur_level->author );
             name = strdup( edit_cur_level->name );
             level_delete( edit_levels[edit_cur_level_id] );
@@ -506,14 +506,14 @@ void editor_handle_button( int type, int *full_update ) {
             break;
         case BUTTON_ADD:
             if ( edit_level_count == MAX_LEVELS ) break;
-            if ( !confirm( font, "Add Level? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Add Level? y/n"), CONFIRM_YES_NO ) ) break;
             edit_levels[edit_level_count] = level_create_empty( edit_levels[edit_level_count - 1]->author, edit_levels[edit_level_count - 1]->name );
             edit_level_count++;
             *full_update = 1;
             break;
         case BUTTON_INSERT:
             if ( edit_level_count == MAX_LEVELS ) break;
-            if ( !confirm( font, "Insert Level? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Insert Level? y/n"), CONFIRM_YES_NO ) ) break;
             for ( i = edit_level_count; i > edit_cur_level_id; i-- )
                 edit_levels[i] = edit_levels[i - 1];
             edit_level_count++;
@@ -523,7 +523,7 @@ void editor_handle_button( int type, int *full_update ) {
             break;
         case BUTTON_DELETE:
             if ( edit_level_count == 1 ) break; /* last level may not be removed */
-            if ( !confirm( font, "Delete Level? y/n", CONFIRM_YES_NO ) ) break;
+            if ( !confirm( font, _("Delete Level? y/n"), CONFIRM_YES_NO ) ) break;
             level_delete( edit_levels[edit_cur_level_id] );
             for ( i = edit_cur_level_id; i < edit_level_count - 1; i++ )
                 edit_levels[i] = edit_levels[i + 1];
@@ -545,7 +545,7 @@ void editor_handle_button( int type, int *full_update ) {
             *full_update = 1;
             break;
         case BUTTON_VERSION:
-            if ( enter_string( font, "Levelset Version:", edit_version, 8 ) ) {
+            if ( enter_string( font, _("Levelset Version:"), edit_version, 8 ) ) {
                 parse_version( edit_version, &version, &update );
                 sprintf( edit_version, "%i.%02i", version, update );
                 *full_update = 1;
@@ -638,13 +638,13 @@ void editor_handle_click( int x, int y, int set, int *full_update )
     /* name&author */
     strcpy( str, "" );
     if ( edit_buttons[x][y] == BUTTON_EDIT_AUTHOR )
-        if ( enter_string( font, "Author's Name:", str, 24 ) ) {
-            snprintf( edit_cur_level->author, 31, str );
+        if ( enter_string( font, _("Author's Name:"), str, 24 ) ) {
+            snprintf( edit_cur_level->author, 31, "%s", str );
             *full_update = 1;
         }
     if ( edit_buttons[x][y] == BUTTON_EDIT_NAME )
-        if ( enter_string( font, "Title:", str, 24 ) ) {
-            snprintf( edit_cur_level->name, 31, str );
+        if ( enter_string( font, _("Title:"), str, 24 ) ) {
+            snprintf( edit_cur_level->name, 31, "%s", str );
             *full_update = 1;
         }
     /* sel frame tile position */
@@ -782,7 +782,7 @@ void editor_run()
                 case SDL_KEYDOWN:
                     switch ( event.key.keysym.sym ) {
                         case SDLK_ESCAPE:
-                            if ( confirm( font, "Quit Editor? y/n", CONFIRM_YES_NO ) ) leave = 1;
+                            if ( confirm( font, _("Quit Editor? y/n"), CONFIRM_YES_NO ) ) leave = 1;
                             break;
                         case SDLK_LEFT: editor_handle_button( BUTTON_PREV, &full_update ); break;
                         case SDLK_RIGHT: editor_handle_button( BUTTON_NEXT, &full_update ); break;
