@@ -32,12 +32,14 @@ enum {
 	CS_LOOSE_LIFE,	/* take a snapshot and decrease lives */
 	CS_ROUND_RESULT,/* await click and start level receive after it */
 	CS_GAME_OVER,	/* all levels are played */
-	CS_CONFIRM_WARP,
+    CS_CONFIRM_WARP,
 	CS_CONFIRM_QUIT,
 	CS_CONFIRM_RESTART,
-        CS_CONFIRM_CONTINUE,
+    CS_CONFIRM_CONTINUE,
 	CS_FATAL_ERROR,	/* display error and quit game after it */
-	CS_PAUSE
+	CS_PAUSE,
+    CS_BONUS_LEVEL_SCORE, /* show score gained in bonus level */
+    CS_GET_READY_FOR_NEXT_LEVEL /* wait for click when showing score of bonus level */
 };
 
 /* create various resources like shrapnells */
