@@ -144,15 +144,19 @@ int confirm( StkFont *font, char *str, int type )
 					}
                 }
                 else
-                switch (event.key.keysym.sym) {
-                    case SDLK_y:
+                {
+                    char *keyName = SDL_GetKeyName(event.key.keysym.sym);
+                    char *yesLetter = _("y");
+                    char *noLetter = _("n");
+                    if (strcmp(keyName, yesLetter) == 0) {
                         go_on = 0;
                         ret = 1;
-                        break;
-                    case SDLK_ESCAPE:
-                    case SDLK_n:
+                    }
+                    else
+                    if (event.key.keysym.sym==SDLK_ESCAPE || strcmp(keyName, noLetter) == 0 ) {
                         go_on = 0;
                         ret = 0;
+                    }
                     default:
                         break;
                 }
@@ -205,7 +209,7 @@ int display_info( StkFont *font, char *str, NetSocket *peer )
     stk_wait_for_input();
     net_write_empty_msg( peer, MSG_READY ); 
 	draw_confirm_screen( font, buffer, 
-                         "Waiting for remote answer..." );
+                         _("Waiting for remote answer...") );
     stk_display_update( STK_UPDATE_ALL );
     event_clear_sdl_queue();
     while ( !leave ) {
@@ -224,7 +228,7 @@ int display_info( StkFont *font, char *str, NetSocket *peer )
                     break;
                 case MSG_GAME_EXITED:
                     ret = 0; leave = 1;
-                    sprintf( error, "remote player cancelled the game\n" );
+                    sprintf( error, /* xgettext:no-c-format */ _("remote player cancelled the game\n") );
                     confirm( font, error, CONFIRM_ANY_KEY );
                     break;
             }
@@ -411,7 +415,7 @@ void game_nuke( void )
 					i*BRICK_WIDTH, j*BRICK_HEIGHT, 128 );
 	/* info */
 	font->align = STK_FONT_ALIGN_LEFT;
-	sprintf( buf, "Plane Of Inner Stability entered (Score: %i)",
+	sprintf( buf, _("Plane Of Inner Stability entered (Score: %i)"),
 			l_paddle->player->stats.total_score + l_paddle->score );
 	stk_font_write( font, stk_display,
 			BRICK_WIDTH, (MAP_HEIGHT-1)*BRICK_HEIGHT, 
@@ -429,11 +433,12 @@ void game_nuke( void )
 			case SDL_MOUSEBUTTONDOWN:
 				if ( x != -1 )
 				if ( confirm( font, 
-					"Disintegrate Brick? (Costs 5% of your score.) y/n", 
+					/* xgettext:no-c-format */ _("Disintegrate Brick? (Costs 5% of your score.) y/n"), 
 					CONFIRM_YES_NO ) ) {
 					/* implant a bomb to this brick and return */
 					game_set_current( local_game );
-					brick_start_expl( x,y, local_game->paddles[0] );
+					brick_start_expl( x,y, BRICK_EXP_TIME,
+							  local_game->paddles[0] );
 					local_game->bricks[x][y].score = 0;
 					game_set_current( game );
 					l_paddle->player->stats.total_score -= (int)(0.05 * 
@@ -498,7 +503,7 @@ void display_text( StkFont *font, char *format, ... )
 	vsnprintf( buf, 512, format, args );
 	va_end( args );
 
-        stk_surface_gray( stk_display, 0,0,-1,-1, 2 );
+    stk_surface_gray( stk_display, 0,0,-1,-1, 2 );
 	text = create_text( buf, 60 );
 	font->align = STK_FONT_ALIGN_CENTER_X | STK_FONT_ALIGN_TOP;
 	y = (stk_display->h - text->count * font->height) / 2;
@@ -511,4 +516,3 @@ void display_text( StkFont *font, char *format, ... )
 
 	stk_display_update( STK_UPDATE_ALL );
 }
-
