@@ -1,4 +1,5 @@
 #include "net.h"
+#include "../client/lbreakout.h"
 #include <SDL.h>
 #include <string.h>
 #include <stdlib.h>
@@ -64,7 +65,7 @@ static bool resolve_hostname( char *host, struct sockaddr *sa, int *sa_len )
 	
 	/* resolve the host's address via DNS lookup */
 	if ( ( hostlist = gethostbyname( host ) ) == 0 ) {
-		sys_printf( "unable to resolve %s: %s\n", host, strerror( errno) );
+		sys_printf( _("unable to resolve %s: %s\n"), host, strerror( errno) );
 		return 0;
 	}
 	
@@ -134,7 +135,7 @@ bool net_init( int port )
 #else
     struct sockaddr_in sa;
     int sa_len;
-    int fcntl_args, i;
+    int fcntl_args, i, new_args;
 
     if ( (net_socket = socket( PF_INET, SOCK_DGRAM, IPPROTO_UDP)) < 0 )
         sys_printf( "couldn't create socket: %s\n", strerror(errno) );
@@ -142,7 +143,13 @@ bool net_init( int port )
         if ( fcntl( net_socket, F_GETFL, &fcntl_args) < 0 )
             sys_printf( "couldn't get fcntl args: %s\n", strerror(errno) );
         else
-            if ( fcntl( net_socket, F_SETFL, O_NONBLOCK | fcntl_args) < 0 )
+        {
+            new_args = O_NONBLOCK;
+            /* no idea, no idea... fcntl seems to work differently since kernel 2.6 
+            if (fcntl_args&O_APPEND) new_args|=O_APPEND;
+            if (fcntl_args&O_ASYNC)  new_args|=O_ASYNC;
+            if (fcntl_args&O_DIRECT) new_args|=O_DIRECT;*/
+            if ( fcntl( net_socket, F_SETFL, new_args ) < 0 )
                 sys_printf( "couldn't set fcntl args: %s\n", strerror(errno) );
             else {
                 sa_len = sizeof(sa);
@@ -162,11 +169,12 @@ bool net_init( int port )
                 }
 
                 net_get_local_addr( port );
-                sys_printf( "UDP socket bound to %s:%i\n", 
+                sys_printf( _("UDP socket bound to %s:%i\n"), 
                         net_addr_to_string( &net_local_addr ), port ); 
 
                 return 1;
             }
+        }
     return 0;
 #endif
 #else
@@ -755,4 +763,3 @@ bool socket_process_header( NetSocket *sock )
 
 	return 1;
 }
-
