@@ -22,27 +22,27 @@
 #include "tools.h"
 
 /* compares to strings and returns true if their first strlen(str1) chars are equal */
-inline int strequal( char *str1, char *str2 )
+int strequal( char *str1, char *str2 )
 {
     if ( strlen( str1 ) != strlen( str2 ) ) return 0;
     return ( !strncmp( str1, str2, strlen( str1 ) ) );
 }
 
 /* set delay to ms milliseconds */
-inline void delay_set( Delay *delay, int ms )
+void delay_set( Delay *delay, int ms )
 {
     delay->limit = ms;
     delay->cur = 0;
 }
 
 /* reset delay ( cur = 0 )*/
-inline void delay_reset( Delay *delay )
+void delay_reset( Delay *delay )
 {
     delay->cur = 0;
 }
 
 /* check if times out and reset */
-inline int delay_timed_out( Delay *delay, int ms )
+int delay_timed_out( Delay *delay, int ms )
 {
     delay->cur += ms;
     if ( delay->cur >= delay->limit ) {
@@ -55,7 +55,7 @@ inline int delay_timed_out( Delay *delay, int ms )
 }
 
 
-inline void goto_tile( int *x, int *y, int d )
+void goto_tile( int *x, int *y, int d )
 {
     /*  0 -up, clockwise, 5 - left up */
     switch ( d ) {
@@ -196,7 +196,7 @@ Text* create_text( char *orig_str, int char_width )
 
     /* change some spaces to new_lines, so that the new text fits the wanted line_length */
     /* NOTE: '#' means new_line ! */
-    // if character with is 0 it's just a single line //
+    // if character width is 0 it's just a single line //
     if ( char_width > 0 ) {
         pos = 0;
         while ( pos < strlen( str ) ) {
@@ -383,5 +383,3 @@ int is_alphanum( char *str )
             return 0;
     return 1;
 }
-
-
