@@ -123,6 +123,7 @@ enum {
 	HT_HEAL,	/* negative hit: regeneration */
 	HT_REMOVE,	/* remove brick completely */
 	HT_GROW,	/* create brick with random color */
+	HT_REMOVE_NO_SOUND, /* is mapped to HT_REMOVE and no_sound=1 */
 
 	/* balls */
 	BALL_NORMAL = 0,
@@ -155,16 +156,26 @@ enum {
 	SHOW_CREDIT,
 
 	/* levels */
-	MAX_LEVELS = 40
+	MAX_LEVELS = 40,
+
+	/* bonus level types (start at 2) */
+	LT_JUMPING_JACK = 2,
+    LT_OUTBREAK,
+    LT_BARRIER,
+    LT_SITTING_DUCKS,
+    LT_HUNTER,
+	LT_DEFENDER,
+    LT_LAST
 };
 
 typedef struct Level {
-	char 	author[32], name[32];
-	/* extras and bricks are saved by their specific character and
-	   interpreted by bricks_create later */
-	char 	bricks[EDIT_WIDTH][EDIT_HEIGHT];
-	char 	extras[EDIT_WIDTH][EDIT_HEIGHT];
-        int     normal_brick_count;
+  char 	author[32], name[32];
+  /* extras and bricks are saved by their specific character and
+     interpreted by bricks_create later */
+  char 	bricks[EDIT_WIDTH][EDIT_HEIGHT];
+  char 	extras[EDIT_WIDTH][EDIT_HEIGHT];
+  int   normal_brick_count;
+  int   type; /* normal or type of bonus level */
 } Level;
 typedef struct {
 	char	name[20];
@@ -349,10 +360,13 @@ typedef struct {
   int x,y;	/* position */
   int type;	/* destruction, hit, regeneration, growth */
   int dest_type;/* shot, normal, energy, explosion */
-  /* if paddle was destroyed: */
+  /* if brick will grow: */
+  int brick_id; /* brick id */
+  /* if brick was destroyed: */
   int paddle; 	/* 0 bottom, 1 top */
   int gold_shower;/* goldshower extra released? */
   int draw_explosion;  /* draw an explosion on destruction */
+  int no_sound; /* play no sound on destruction */
   int degrees; 	/* 0 to 180. *2 degree of normal animation movement */
 } BrickHit;
 
@@ -395,6 +409,12 @@ typedef struct {
 	int		brick_reflected_ball_count;
 } GameMod;
 
+typedef struct {
+	int id;      /* brick id */
+	int x, y;    /* position */
+	Delay delay; /* move delay */
+} Invader;
+
 typedef struct {
 	int		game_type;
         GameDiff	*diff; /* difficulty level */
@@ -434,10 +454,55 @@ typedef struct {
 
 	/* code red modifications from update() */
 	GameMod		mod;
+
+  /* bonus level information */
+  int isBonusLevel;         /* whether we are in a bonus level */
+  int blRefreshBricks;      /* copy all bricks from local to client since brick positions have
+                               changed and redraw; keep anything else */
+  int localServerGame;      /* this is the local_game context, actually handling the game */
+  int totalBonusLevelScore; /* bonus levels are all about gaining extra score so we count it */
+  int blNumCompletedRuns;   /* number of successful runs (how often score was added) */
+  double blRatioSum;        /* some of all ratios; devided by blNumCompletedRuns we get an average */
+  int blActionTime;         /* e.g.,brick dies/grows after that time */
+  Delay blDelay;            /* e.g., new brick after this times out or barrier moves down */
+  int blMaxScore;           /* maximum score for current run */
+  int bl_jj_mx, bl_jj_my;   /* position of current jumping jack */
+  int blCancerCount;        /* number of bricks grown so far, must not exceed bl_cancer_limit */
+  int blCancerLimit;        /* game over if this many bricks sprung into existence */
+  int blBarrierLevel;       /* size of barrier */
+  int blBarrierMoves;       /* how often barrier has moved in this run */
+  int blBarrierMaxMoves;    /* max number of possible moves before game over */
+  int blTotalNumDucks;      /* total number of ducks */
+  int blNumDucks;           /* number of active ducks */
+  int *blDuckPositions;     /* position of ducks */
+  int blBallAttached;       /* ball waits at ceiling */
+  int blCurrentDuck;        /* id in duck positions [id*2,id*2+1] */
+  int blDuckBaseScore;      /* maxScore is reset to this if miss */
+  int blHunterAreaX1;
+  int blHunterAreaY1;       /* left upper corner of playingfield frame */
+  int blHunterAreaX2;
+  int blHunterAreaY2;       /* right lower corner of playingfield frame */
+  int blHunterUpId;
+  int blHunterDownId;
+  int blHunterRightId;
+  int blHunterLeftId;       /* ids of brick types for control */
+  int blHunterId;
+  int blHunterPreyId;
+  int blHunterX,blHunterY;  /* position of hunter */
+  int blHunterPreyX;
+  int blHunterPreyY;        /* position of pray */
+  int blHunterTimeLeft;
+  int blInvaderLimit;       /* max number of invaders */
+  int blNumInvaders;        /* current number of invaders */
+  int blNumKilledInvaders;  /* already destroyed in this wave */
+  int blTotalNumKilledInvaders;  /* already destroyed total */
+  int blInvadersWaveOver;
+  int blInvaderTime;        /* within a wave invaders will speed up too */
+  int blInvaderScore;       /* score per invader kill */
+  Invader *blInvaders;      /* current positions */
 } Game;
 
 #define SETBIT( data, bit ) data |= (1L << bit )
 #define GETBIT( data, bit ) ((data >> bit) & 1)
 
 #endif
-
