@@ -298,7 +298,7 @@ void server_game_add( ServerChannel *channel, ServerGameCtx *ctx )
 	}
 
 	list_add( games, game );
-	printf( "game added: %s (%i): %i rounds: %s vs. %s\n", 
+	printf( _("game added: %s (%i): %i rounds: %s vs. %s\n"), 
 		game->set->name, game->id, game->rounds, 
 		game->users[0]->name, game->users[1]->name );
 }
@@ -309,7 +309,7 @@ void server_game_delete( void *ptr )
 	ServerGame *game = (ServerGame*)ptr;
 	
 	if ( game ) {
-		printf( "game deleted: %s (%i)\n", game->set->name, game->id );
+		printf( _("game deleted: %s (%i)\n"), game->set->name, game->id );
 		
 		if ( game->game )
 			game_delete( &game->game );
@@ -391,10 +391,10 @@ void parse_packet_game( ServerGame *game, ServerUser *user )
 					peer = game->users[1];
 				else
 					peer = game->users[0];
-				send_info( peer, MSG_ERROR, "Remote player has disconnected..." );
+				send_info( peer, MSG_ERROR, _("Remote player has disconnected...") );
 
 				server_game_remove( game );
-                                printf( "%s (%i) disconnected\n", user->name, user->id );
+                                printf( _("%s (%i) disconnected\n"), user->name, user->id );
 				channel_remove_user( game->channel, user );
 				handled = 1;
 				break;
@@ -403,7 +403,7 @@ void parse_packet_game( ServerGame *game, ServerUser *user )
 					peer = game->users[1];
 				else
 					peer = game->users[0];
-				send_info( peer, MSG_ERROR, "Remote player has left the game..." );
+				send_info( peer, MSG_ERROR, _("Remote player has left the game...") );
 				
 				/* update stats and finalize context */
 				game->game->winner = -1; /* count unfinished level as draw */
@@ -530,7 +530,7 @@ void parse_packet_game( ServerGame *game, ServerUser *user )
 		}
 
 		if ( !handled ) {
-			printf( "game %i: %s: state %i: invalid message %x: skipping %i bytes\n",
+			printf( _("game %i: %s: state %i: invalid message %x: skipping %i bytes\n"),
 				game->id, net_addr_to_string( &user->socket.remote_addr ),
 				game->state, type, net_buffer_cur_size - msg_read_pos );
 			msg_read_pos = net_buffer_cur_size;
